holiness
========

|PyPI| |GitHub-license| |Requires.io| |Travis|

Built from `makenew/python-package <https://github.com/makenew/python-package>`__.

.. |PyPI| image:: https://img.shields.io/pypi/v/holiness.svg
   :target: https://pypi.python.org/pypi/holiness
   :alt: PyPI
.. |GitHub-license| image:: https://img.shields.io/github/license/MadaoG/holiness.svg
   :target: ./LICENSE.txt
   :alt: GitHub license
.. |Requires.io| image:: https://img.shields.io/requires/github/MadaoG/holiness.svg
   :target: https://requires.io/github/MadaoG/holiness/requirements/
   :alt: Requires.io
.. |Travis| image:: https://img.shields.io/travis/MadaoG/holiness.svg
   :target: https://travis-ci.org/MadaoG/holiness
   :alt: Travis

Description
-----------

Produces nice headlines

Installation
------------

This package is registered on the `Python Package Index (PyPI)`_
as `holiness_`.

Install it using pip with

::

    $ pip install holiness


Development and Testing
-----------------------

Source Code
~~~~~~~~~~~

The `holiness source`_ is hosted on GitHub.
Clone the project with

::

    $ git clone https://github.com/MadaoG/holiness.git

.. .. _holiness source: https://github.com/MadaoG/holiness

.. Requirements
.. ~~~~~~~~~~~~

.. You will need `Python 3`_ with pip_.

.. Tests
.. ~~~~~

.. Run tests with

.. ::

..     $ python setup.py test

.. You need `nose` for this. Install it with pip.

.. Contributing
.. ------------

.. Please submit and comment on bug reports and feature requests.

.. To submit a patch:

.. 1. Fork it (https://github.com/MadaoG/holiness/fork).
.. 2. Create your feature branch (``git checkout -b my-new-feature``).
.. 3. Make changes. Write and run tests.
.. 4. Commit your changes (``git commit -am 'Add some feature'``).
.. 5. Push to the branch (``git push origin my-new-feature``).
.. 6. Create a new Pull Request.

.. License
.. -------

.. This Python package is licensed under the MIT license.

.. Warranty
.. --------

.. This software is provided "as is" and without any express or implied
.. warranties, including, without limitation, the implied warranties of
.. merchantibility and fitness for a particular purpose.
